Package: phenoTest
Type: Package
Title: Tools to test association between gene expression and phenotype
        in a way that is efficient, structured, fast and scalable. We
        also provide tools to do GSEA (Gene set enrichment analysis)
        and copy number variation.
Version: 1.60.0
Date: 2013-05-29
Author: Evarist Planet
Maintainer: Evarist Planet <evarist.planet@epfl.ch>
Description: Tools to test correlation between gene expression and
        phenotype in a way that is efficient, structured, fast and
        scalable. GSEA is also provided.
License: GPL (>=2)
Depends: R (>= 3.6.0), Biobase, methods, annotate, Heatplus, BMA,
        ggplot2, Hmisc
Imports: survival, limma, gplots, Category, AnnotationDbi, hopach,
        biomaRt, GSEABase, genefilter, xtable, annotate, mgcv,
        hgu133a.db, ellipse
Suggests: GSEABase, GO.db
Enhances: parallel, org.Ce.eg.db, org.Mm.eg.db, org.Rn.eg.db,
        org.Hs.eg.db, org.Dm.eg.db
LazyLoad: yes
biocViews: Microarray, DifferentialExpression, MultipleComparison,
        Clustering, Classification
Config/pak/sysreqs: cmake make libicu-dev libpng-dev libuv1-dev
        libxml2-dev libssl-dev zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:35:04 UTC
RemoteUrl: https://github.com/bioc/phenoTest
RemoteRef: RELEASE_3_23
RemoteSha: 540df6461fb5aca9093c0479501caf9153dded67
NeedsCompilation: no
Packaged: 2026-04-29 23:50:03 UTC; root
Built: R 4.6.0; ; 2026-04-30 01:25:34 UTC; unix
