importClassesFrom(Biobase, ExpressionSet, eSet, VersionedBiobase, Versioned)

export(summary.gseaSignificanceSign, summary.gseaSignificanceVar, plot.gseaSignaturesSign,
       plot.gseaSignaturesVar, ExpressionPhenoTest, epheno2html,heatmapPhenoTest,
       ClusterPhenoTest, smoothCoxph, getEsPositions, findCopyNumber, genesInArea,
       gsea, summary.gseaData, plot.gseaData, gsea2html, gsea.selVars, gsea.selGsets, 
       eset2genelevel, write.html, pca)

exportClasses("epheno","gseaSignatures","gseaSignaturesSign","gseaSignaturesVar",
              "gseaSignificanceSign","gseaSignificanceVar")

exportMethods(gseaSignatures, gseaSignificance, getEs, getEsSim, getFcHr, dim, phenoNames,
              p.adjust.method, approach, phenoClass, show, getMeans, getPvals, getPostProbs,
              getSignif, getSummaryDif, getFc, getHr, logFcHr, export2CSV, "[",
              barplotSignatures, barplotSignifSignatures, pAdjust, getVars2test)

importClassesFrom(GSEABase, GeneSet, GeneSetCollection)

importMethodsFrom(AnnotationDbi, head)

importMethodsFrom(GSEABase, geneIds)

importMethodsFrom(genefilter, nsFilter, plot)

importFrom(Category, ttperm)

importFrom(Hmisc, cut2)

importFrom(biomaRt, getLDS, useMart)

importFrom(gplots, barplot2, greenred)

importFrom(hopach, distancematrix)

importFrom(limma, contrasts.fit, eBayes, lmFit)

importFrom(survival, Surv, coxph, survfit, pspline)

importFrom(xtable, xtable)

importFrom(mgcv, gam, s, predict.gam)

importFrom(hgu133a.db, hgu133aCHR, hgu133aCHRLOC, hgu133aCHRLOCEND)

importFrom(ellipse, ellipse)
